@@ -10,6 +10,16 @@ from io import BytesIO
 
 logger = logging.getLogger(__name__)
 
+def read_object(file, mode='r', encoding='utf-8'):
+    """
+    返回文件对象
+    :param file:
+    :param mode:
+    :param encoding:
+    :return:
+    """
+    f =  open(file, mode, encoding=encoding)
+    return f
 
 def read_file(file, mode='r', encoding='utf-8'):
     """
