@@ -26,8 +26,9 @@ class BaseMSG:
         return res
 
 
-session = requests.Session()
-session.keep_alive = False
+#
+# session = requests.Session()
+# session.keep_alive = False
 
 
 # def change_user_agent():
@@ -37,10 +38,13 @@ session.keep_alive = False
 #     session.headers['X-forwarded-for'] = '49.49.49.49'
 
 
-def safe_requests(url, method, **kwargs):
+def safe_requests(url, method, session=None, **kwargs):
     # change_user_agent()
     try:
-        res = session.request(url=url, method=method, **kwargs)
+        if session:
+            res = session.request(url=url, method=method, **kwargs)
+        else:
+            res = requests.request(url=url, method=method, **kwargs)
         return res
     except Exception as e:
         if 'Failed to establish a new connection:' in str(e):
@@ -61,22 +65,22 @@ def _check_whos_guo(url, res):
         logger.warning("访问 {} 返回状态码 {}\n文本内容为 {}".format(res.url, res.status_code, res.text))
 
 
-def get_html(url):
-    res = safe_requests(url, method='GET')
+def get_html(url, session=None):
+    res = safe_requests(url, session=session, method='GET')
     if isinstance(res, Response):
         if res.status_code == 200:
             return res.text
     return False
 
 
-def get_cookie(url):
-    res = safe_requests(url, method='GET')
+def get_cookie(url, session=None):
+    res = safe_requests(url, session=None, method='GET')
     return res.cookies
 
 
-def post_data(url, data, encode='utf-8', check_whos_guo=False):
+def post_data(url, data, session=None, encode='utf-8', check_whos_guo=False):
     """以字符串形式发送数据"""
-    res = safe_requests(url, method='POST', data=str(data).encode(encode))
+    res = safe_requests(url, session=session, method='POST', data=str(data).encode(encode))
     if isinstance(res, Response):
         if res.status_code == 200:
             return res
@@ -86,7 +90,7 @@ def post_data(url, data, encode='utf-8', check_whos_guo=False):
     return False
 
 
-def post_json_data(url, data, check_whos_guo=False):
+def post_json_data(url, data, session=None, check_whos_guo=False):
     """以json形式发送数据"""
     if isinstance(data, dict):
         pass
@@ -95,7 +99,7 @@ def post_json_data(url, data, check_whos_guo=False):
             data = [data]
         data = dict(enumerate(data))
 
-    res = safe_requests(url, method='POST', json=data)
+    res = safe_requests(url, session=session, method='POST', json=data)
     if isinstance(res, Response):
         if res.status_code == 200:
             return res
@@ -104,6 +108,8 @@ def post_json_data(url, data, check_whos_guo=False):
         _check_whos_guo(url, res)
     return False
 
+def get(url, session=None, **kwargs):
+    return safe_requests(url, session=session, method='GET', **kwargs)
 
-def post(url, **kwargs):
-    return safe_requests(url, method='POST', **kwargs)
+def post(url, session=None, **kwargs):
+    return safe_requests(url, session=session, method='POST', **kwargs)
